@@ -469,9 +469,8 @@ class LaharFlowData(object):
     def raster(self, filename, full_domain=False, nodata=np.nan, masked=True, crs=None):
         filetype = self._file_type(filename)
         
-        if filetype == 'snapshot':
-            filename = '{0:06d}.txt'.format(filename)
-
+        filename = self._valid_input_file(filename)
+        
         if self.zipped:
             LaharFlowFilePath = _path_of_file_in_zip(filename, self._zipref)[0]
             LaharFlowFile = self._zipref.extract(LaharFlowFilePath, path=self.dir)
